/***************************************************************************
 *   Copyright Brian Ledbetter 2001-2003 <brian@shadowcom.net>             *
 *   Copyright Ravikiran Rajagopal 2003                                    *
 *   ravi@ee.eng.ohio-state.edu                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License (version 2) as   *
 *   published by the Free Software Foundation. (The original KSplash/ML   *
 *   codebase (upto version 0.95.3) is BSD-licensed.)                      *
 *                                                                         *
 ***************************************************************************/

#include <kapplication.h>
#include <kdebug.h>
#include <kglobalsettings.h>
#include <kpixmap.h>
#include <kwin.h>

#include <qlabel.h>
#include <qwidget.h>

#include "iconbar.h"
#include "iconbar.moc"

IconBar::IconBar()
    : QLabel( 0L, 0L, WStyle_Customize|WStyle_StaysOnTop|WStyle_NoBorderEx )
{
  KWin::setState( winId(), NET::Modal | NET::StaysOnTop | NET::SkipTaskbar | NET::SkipPager );
  KWin::setType( winId(), NET::Dock );
  setPalette( Qt::black );
  resize( 0, 0 );
}

IconBar::~IconBar()
{
  mIcons.clear();
}

void IconBar::appendIcon( Icon *i )
{
  mIcons.append( i );
  connect( i, SIGNAL( sizeChanged() ), this, SLOT( positionIcons() ) );
  i->show();
  positionIcons();
}

void  IconBar::positionIcons()
{
  QRect desk(KGlobalSettings::splashScreenDesktopGeometry());

  if( !mIcons.count() )
  {
    resize( 0, 0 );
    return;
  }

  //int minPosition = 0;
  //int maxHeight = 0;
  int totalWidth = 0;
  int accumulatedWidth = 0;

  // Step 1: Determine the width of ALL of our icons.
  QValueList< int > x;
  QListIterator<Icon> it( mIcons );
  while( it.current() )
  {
    if( it.current()->height() != it.current()->width() )
    {
      x.clear();
      return;
    }
    x.append( it.current()->width() );
    totalWidth += it.current()->width();
    ++it;
  }

  // For each icon...
  for( unsigned int i = 0; i < x.count(); i++ )
  {
    // Move the icon to STARTINGPOS + ACCUMULATEDWIDTH.
    mIcons.at( i )->move(
      (desk.width() / 2) - (totalWidth/2) + accumulatedWidth,
      desk.height() - mIcons.at( i )->height() - 3
    );

    // Update the ACCUMULATED WIDTH to reflect new information.
    accumulatedWidth += x[i];
  }

  x.clear();

  // Adjust our iconbar to reflect where we are.
  resize( totalWidth, 3 );
}

void  IconBar::resizeEvent( QResizeEvent *qre )
{
  QLabel::resizeEvent( qre );
  QRect r(KGlobalSettings::splashScreenDesktopGeometry());
  move( r.width()/2 - qre->size().width()/2, r.height() - qre->size().height());
}
